@@ -2,6 +2,7 @@
 #'
 #' Classifies something.
 #' Generic, with method \code{\link{classified.default}}
+#' @aliases NULL classified_generic
 #' @param x object of dispatch
 #' @param ... passed arguments
 #' @export
@@ -25,6 +26,7 @@ classified <- function(x, ...)UseMethod('classified')
 #' @param exclude see \code{\link{factor}}
 #' @param ordered see \code{\link{factor}}
 #' @param nmax see \code{\link{factor}}
+#' @param token informative label for messages
 #' @param ... ignored
 #' @importFrom dplyr distinct
 #' @family classified
@@ -39,13 +41,15 @@ classified.factor <- function(
     exclude = NA,
     ordered = is.ordered(x),
     nmax = NA,
+    token = character(0),
     ...
 ){
+  stopifnot(is.character(token), length(token) <= 1)
   if(missing(levels)) levels <- match.fun('levels')(x)
   levels <- setdiff(levels, exclude)
   if(missing(labels)) labels <- levels
   stopifnot(identical(length(levels), length(labels)))
-  if(any(duplicated(labels)))(stop('duplicated labels not supported in this context'))
+  if(any(duplicated(labels)))(stop(paste( collapse = ': ', c(token, 'duplicated labels not supported in this context'))))
   y <- classified.default(
     x,
     levels = levels,
@@ -70,6 +74,7 @@ classified.factor <- function(
 #' length of labels cannot be one (i.e., different from
 #' length of levels).
 #'
+#' @aliases classified
 #' @export
 #' @return 'classified' 'factor'
 #' @param x see \code{\link{factor}}
@@ -78,6 +83,7 @@ classified.factor <- function(
 #' @param exclude see \code{\link{factor}}
 #' @param ordered see \code{\link{factor}}
 #' @param nmax see \code{\link{factor}}
+#' @param token informative label for messages
 #' @param ... ignored
 #' @importFrom dplyr distinct
 #' @family classified
@@ -103,6 +109,7 @@ classified.default <- function(
   exclude = NA,
   ordered = is.ordered(x),
   nmax = NA,
+  token = character(0),
   ...
 ){
   cl <- attr(x,'codelist') # could be NULL
@@ -141,7 +148,15 @@ classified.default <- function(
 
   # at this point, levels and labels should have matching length
   # should be true using defaults
-  if(length(levels) != length(labels))stop('classified requires labels and levels of the same length')
+  if(length(levels) != length(labels))stop(
+    paste(
+      collapse = ': ',
+      c(
+        token,
+        'classified requires labels and levels of the same length'
+      )
+    )
+  )
 
   # under some circumstances, levels has names, which may be NA
   # then data.frame inherits NA rownames which is an error.
@@ -150,19 +165,21 @@ classified.default <- function(
   codes <- data.frame(levels = levels, labels = labels)
   if(any(duplicated(codes))){
     duplicated <- anyDuplicated(codes)
-    warning(
+    msg <- paste0(
       'dropping duplicated levels, e.g.: ', 
       codes$levels[[duplicated]], 
       ' (', 
       codes$labels[[duplicated]],
-      ')'
+       ')'      
     )
+    msg <- paste(collapse = ': ', c(token, msg))
+    warning(msg)
     codes <- unique(codes)
   }
   
   if(any(duplicated(codes$levels))){
     duplicated <- anyDuplicated(codes$levels)
-    warning(
+    msg <- paste0(
       'level(s) cross-labelled, e.g.: ', 
       codes$levels[[duplicated]], 
       ': ', 
@@ -171,15 +188,19 @@ classified.default <- function(
         codes$labels[codes$levels == codes$levels[[duplicated]]]
       )
     )
+    msg <- paste(collapse = ': ', token, msg)
+    warning(msg)
   }
   if(any(duplicated(codes$labels))){
     duplicated <- anyDuplicated(codes$labels)
-    warning(
+    msg <- paste0(
       'levels like-labelled, e.g.: ', 
       paste(collapse = ', ', codes$levels[codes$labels == codes$labels[[duplicated]]]), 
       ': ', 
       codes$labels[[duplicated]]
     )
+    msg <- paste(collapse = ': ', token, msg)
+    warning(msg)
   }
   
   # having dropped any duplicates, we unpack codes
@@ -472,7 +493,8 @@ classified.data.frame <- function(
         x[[nm]],
         exclude = exclude,
         ordered = ordered,
-        nmax = nmax
+        nmax = nmax,
+        token = nm
       )
     }
   }
@@ -491,6 +513,7 @@ classified.data.frame <- function(
 #' @param exclude see \code{\link{factor}}
 #' @param ordered see \code{\link{factor}}
 #' @param nmax see \code{\link{factor}}
+#' @param token informative label for messages
 #' @export
 #' @keywords internal
 #' @return classified
@@ -509,7 +532,8 @@ classified.dvec <- function(
     ...,
     exclude = NA,
     ordered = is.ordered(x),
-    nmax = NA
+    nmax = NA,
+    token = character(0)
 ){
   y <- unclass(x)
   y <- classified(
@@ -517,6 +541,7 @@ classified.dvec <- function(
     exclude = exclude,
     ordered = ordered,
     nmax = nmax,
+    token = token,
     ...
   )
   y
